@@ -73,10 +73,10 @@ FollowUpReminderSelectDateDialog::FollowUpReminderSelectDateDialog(QWidget *pare
     mainLayout->addLayout(formLayout);
 
     d->mDateComboBox = new KDateComboBox;
+    QDate currentDate = QDate::currentDate().addDays(1);
     d->mDateComboBox->setMinimumDate(QDate::currentDate());
     d->mDateComboBox->setObjectName(QStringLiteral("datecombobox"));
 
-    QDate currentDate = QDate::currentDate();
     d->mDateComboBox->setDate(currentDate);
 
     formLayout->addRow(i18n("Date:"), d->mDateComboBox);
@@ -90,7 +90,7 @@ FollowUpReminderSelectDateDialog::FollowUpReminderSelectDateDialog(QWidget *pare
     formLayout->addRow(i18n("Store ToDo in:"), d->mCollectionCombobox);
 
     connect(d->mDateComboBox->lineEdit(), &QLineEdit::textChanged, this, &FollowUpReminderSelectDateDialog::slotDateChanged);
-    connect(d->mCollectionCombobox, QOverload<int>::of(&Akonadi::CollectionComboBox::currentIndexChanged), this, &FollowUpReminderSelectDateDialog::updateOkButton);
+    connect(d->mCollectionCombobox, qOverload<int>(&Akonadi::CollectionComboBox::currentIndexChanged), this, &FollowUpReminderSelectDateDialog::updateOkButton);
     updateOkButton();
 }
 
@@ -125,7 +125,7 @@ Akonadi::Collection FollowUpReminderSelectDateDialog::collection() const
 void FollowUpReminderSelectDateDialog::accept()
 {
     const QDate date = selectedDate();
-    if (date <= QDate::currentDate()) {
+    if (date < QDate::currentDate()) {
         KMessageBox::error(this, i18n("The selected date must be greater than the current date."), i18n("Invalid date"));
         return;
     }
