@@ -29,7 +29,6 @@
 #include "messagepartrendererbase.h"
 #include "messagepartrendererfactory.h"
 #include "htmlblock.h"
-
 #include "utils/iconnamecache.h"
 #include "utils/mimetype.h"
 #include "viewer/attachmentstrategy.h"
@@ -49,7 +48,6 @@
 #include <KIconLoader>
 #include <KLocalizedString>
 
-#include <QApplication>
 #include <QUrl>
 
 #include <grantlee/context.h>
@@ -58,6 +56,8 @@
 #include <grantlee/templateloader.h>
 #include <grantlee/template.h>
 
+#include <qtwebenginewidgetsversion.h>
+
 using namespace MimeTreeParser;
 using namespace MessageViewer;
 
@@ -310,11 +310,14 @@ QString processHtml(const QString &htmlSource, QString &extraHead)
             return htmlSource;
         }
         extraHead = s.mid(startIndex + 6, endIndex - startIndex - 6);
+#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
         //Remove this hack with https://codereview.qt-project.org/#/c/256100/2 is merged
         //Don't authorize to refresh content.
         if (MessageViewer::Util::excludeExtraHeader(s)) {
             extraHead.clear();
         }
+#endif
+
 
         s = s.mid(endIndex + 7).trimmed();
     }
@@ -1145,7 +1148,7 @@ void DefaultRenderer::setHtmlLoadExternal(bool htmlLoadExternal)
     d->mHtmlLoadExternal = htmlLoadExternal;
 }
 
-void DefaultRenderer::setCreateMessageHeader(std::function<QString(KMime::Message *)> createMessageHeader)
+void DefaultRenderer::setCreateMessageHeader(const std::function<QString(KMime::Message *)> &createMessageHeader)
 {
     d->mCreateMessageHeader = createMessageHeader;
 }
