@@ -41,25 +41,25 @@ public:
 
     virtual ~HTMLBlock();
 
-    QString enter();
-    QString exit();
+    Q_REQUIRED_RESULT QString enter();
+    Q_REQUIRED_RESULT QString exit();
 protected:
     QString dir() const;
     virtual QString enterString() const = 0;
     virtual QString exitString() const = 0;
 
 private:
-    bool entered;
+    bool entered = false;
 };
 
-// The attachment mark is a div that is placed around the attchment. It is used for drawing
+// The attachment mark is a div that is placed around the attachment. It is used for drawing
 // a yellow border around the attachment when scrolling to it. When scrolling to it, the border
 // color of the div is changed, see KMReaderWin::scrollToAttachment().
 class MESSAGEVIEWER_EXPORT AttachmentMarkBlock : public HTMLBlock
 {
 public:
     AttachmentMarkBlock(HtmlWriter *writer, KMime::Content *node);
-    virtual ~AttachmentMarkBlock();
+    ~AttachmentMarkBlock() override;
 
 protected:
     QString enterString() const override;
@@ -79,8 +79,8 @@ private:
 class RootBlock : public HTMLBlock
 {
 public:
-    RootBlock(HtmlWriter *writer);
-    virtual ~RootBlock();
+    explicit RootBlock(HtmlWriter *writer);
+    ~RootBlock() override;
 
 protected:
     QString enterString() const override;
