@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,14 +17,12 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #ifndef TEMPLATEPARSEREMAILADDRESSREQUESTERBASE_H
 #define TEMPLATEPARSEREMAILADDRESSREQUESTERBASE_H
 
 #include <QWidget>
 #include "templateparser_export.h"
-namespace TemplateParser
-{
+namespace TemplateParser {
 class TEMPLATEPARSER_EXPORT TemplateParserEmailAddressRequesterBase : public QWidget
 {
     Q_OBJECT
