@@ -29,6 +29,7 @@
 #include <MessageCore/StringUtil>
 
 #include <MimeTreeParser/ObjectTreeParser>
+#include <MimeTreeParser/MessagePart>
 #include <MimeTreeParser/SimpleObjectTreeSource>
 
 #include <KIdentityManagement/Identity>
@@ -296,29 +297,59 @@ void TemplateParserJob::processWithIdentity(uint uoid, const KMime::Message::Ptr
     process(aorig_msg, afolder);
 }
 
+MimeTreeParser::MessagePart::Ptr toplevelTextNode(MimeTreeParser::MessagePart::Ptr messageTree)
+{
+    foreach (const auto &mp, messageTree->subParts()) {
+        auto text = mp.dynamicCast<MimeTreeParser::TextMessagePart>();
+        const auto attach = mp.dynamicCast<MimeTreeParser::AttachmentMessagePart>();
+        if (text && !attach) {
+            // TextMessagePart can have several subparts cause of PGP inline, we search for the first part with content
+            foreach (const auto &sub, mp->subParts()) {
+                if (!sub->text().trimmed().isEmpty()) {
+                    return sub;
+                }
+            }
+            return text;
+        } else if (const auto html = mp.dynamicCast<MimeTreeParser::HtmlMessagePart>()) {
+            return html;
+        } else if (const auto alternative = mp.dynamicCast<MimeTreeParser::AlternativeMessagePart>()) {
+            return alternative;
+        } else {
+            auto ret = toplevelTextNode(mp);
+            if (ret) {
+                return ret;
+            }
+        }
+    }
+    return MimeTreeParser::MessagePart::Ptr();
+}
+
 void TemplateParserJob::processWithTemplate(const QString &tmpl)
 {
     d->mOtp->parseObjectTree(d->mOrigMsg.data());
 
-    TemplateParserExtractHtmlInfo *job = new TemplateParserExtractHtmlInfo(this);
-    connect(job, &TemplateParserExtractHtmlInfo::finished, this, &TemplateParserJob::slotExtractInfoDone);
+    const auto mp = toplevelTextNode(d->mOtp->parsedPart());
 
-    QString plainText = d->mOtp->plainTextContent();
-    if (plainText.isEmpty()) {   //HTML-only mails
-        plainText = d->mOtp->htmlContent();
-    }
+    QString plainText = mp->plaintextContent();
+    QString htmlElement;
 
-    job->setHtmlForExtractingTextPlain(plainText);
-    job->setTemplate(tmpl);
-
-    QString htmlElement = d->mOtp->htmlContent();
-
-    if (htmlElement.isEmpty()) {   //plain mails only
-        QString htmlReplace = d->mOtp->plainTextContent().toHtmlEscaped();
+    if (mp->isHtml()) {
+        htmlElement = d->mOtp->htmlContent();
+        if (plainText.isEmpty()) {   //HTML-only mails
+            plainText = htmlElement;
+        }
+    } else {   //plain mails only
+        QString htmlReplace = plainText.toHtmlEscaped();
         htmlReplace = htmlReplace.replace(QLatin1Char('\n'), QStringLiteral("<br />"));
         htmlElement = QStringLiteral("<html><head></head><body>%1</body></html>\n").arg(htmlReplace);
     }
 
+    TemplateParserExtractHtmlInfo *job = new TemplateParserExtractHtmlInfo(this);
+    connect(job, &TemplateParserExtractHtmlInfo::finished, this, &TemplateParserJob::slotExtractInfoDone);
+
+    job->setHtmlForExtractingTextPlain(plainText);
+    job->setTemplate(tmpl);
+
     job->setHtmlForExtractionHeaderAndBody(htmlElement);
     job->start();
 }
@@ -1483,7 +1514,8 @@ QString TemplateParserJob::plainMessageText(bool aStripSignature, AllowSelection
     if (!d->mOrigMsg) {
         return QString();
     }
-    QString result = d->mOtp->plainTextContent();
+    const auto mp = toplevelTextNode(d->mOtp->parsedPart());
+    QString result = mp->plaintextContent();
     if (result.isEmpty()) {
         result = d->mExtractHtmlInfoResult.mPlainText;
     }
